#!/bin/bash

PROJECTNAME=$(basename "$(pwd)")

# Are you root?
if [ "$EUID" -ne 0 ]; then
    echo -e "\033[0;31mThis script must be run as root.\033[0m"
    exit 1
fi

##################################################################
# ENV file
##################################################################
# Verify the .env file exists
if [ ! -f ".env" ]; then
  echo "Error: The .env file does not exist."
  exit 1
fi

# Load environment variables from .env file
set -o allexport
source .env
set +o allexport

##################################################################
# create json file
##################################################################

#DB_PREFIX=$(echo $RANDOM | md5sum | awk '{print substr($1, 1, 3)}')_

# docker-compose exec -u www-data joomla sh -c "echo '{
#   \"language\":\"en-GB\",
#   \"site_name\":\"$PROJECTNAME\",
#   \"admin_email\":\"$EMAIL\",
#   \"admin_user\":\"$JOOMLA_USER\",
#   \"admin_password\":\"$JOOMLA_PASSWORD\",
#   \"db_type\":\"mysql\",
#   \"db_host\":\"mariadb\",
#   \"db_user\":\"$MYSQL_USER\",
#   \"db_pass\":\"$MYSQL_PASSWORD\",
#   \"db_name\":\"$MYSQL_DATABASE\",
#   \"db_prefix\":\"$DB_PREFIX\",
#   \"db_old\":\"remove\",
#   \"helpurl\":\"https://joomla.org\"
# }' > config.json"

# docker-compose exec -u www-data joomla php cli/joomla.php core:install --file=config.json

##################################################################
# EASY GUI SETUP
##################################################################

# Site Name
xmlstarlet ed -L -s '//field[@name="site_name"]' -t attr -n default -v "$PROJECTNAME" html/installation/forms/setup.xml

# Super User Full Name
xmlstarlet ed -L -s '//field[@name="admin_user"]' -t attr -n default -v "$JOOMLA_USER" html/installation/forms/setup.xml

# Super User username
xmlstarlet ed -L -s '//field[@name="admin_username"]' -t attr -n default -v "$JOOMLA_USER" html/installation/forms/setup.xml

# Super User Password
xmlstarlet ed -L -s '//field[@name="admin_password"]' -t attr -n default -v "$JOOMLA_PASSWORD" html/installation/forms/setup.xml

# Super User email
xmlstarlet ed -L -s '//field[@name="admin_email"]' -t attr -n default -v "$EMAIL" html/installation/forms/setup.xml

# Database  host
xmlstarlet ed -L -u '//field[@name="db_host"]/@default' -v 'mariadb' html/installation/forms/setup.xml

# Database user
xmlstarlet ed -L -s '//field[@name="db_user"]' -t attr -n default -v "$MYSQL_USER" html/installation/forms/setup.xml

# Database password
xmlstarlet ed -L -s '//field[@name="db_pass"]' -t attr -n default -v "$MYSQL_PASSWORD" html/installation/forms/setup.xml

# Database  name
xmlstarlet ed -L -u '//field[@name="db_name"]/@default' -v "$MYSQL_DATABASE" html/installation/forms/setup.xml

